@@ -3,7 +3,7 @@ package IO::File::AtomicChange;
 use strict;
 use warnings;
 
-our $VERSION = '0.07_02';
+our $VERSION = '0.01';
 
 use base qw(IO::File);
 use Carp;
@@ -13,9 +13,9 @@ use File::Copy;
 sub new {
     my $class = shift;
     my $self = $class->SUPER::new();
-    $self->_temp_file("");
-    $self->_target_file("");
-    $self->_backup_dir("");
+    $self->temp_file("");
+    $self->target_file("");
+    $self->backup_dir("");
     $self->open(@_) if @_;
     $self;
 }
@@ -25,9 +25,9 @@ sub _accessor {
     ${*$self}{$tag} = $val if $val;
     return ${*$self}{$tag};
 }
-sub _temp_file   { return shift->_accessor("io_file_atomicchange_temp", @_) }
-sub _target_file { return shift->_accessor("io_file_atomicchange_path", @_) }
-sub _backup_dir  { return shift->_accessor("io_file_atomicchange_back", @_) }
+sub temp_file   { return shift->_accessor("io_file_atomicchange_temp", @_) }
+sub target_file { return shift->_accessor("io_file_atomicchange_path", @_) }
+sub backup_dir  { return shift->_accessor("io_file_atomicchange_back", @_) }
 
 sub DESTROY {
     carp "[CAUTION] disposed object without closing file handle." unless $_[0]->_closed;
@@ -40,15 +40,15 @@ sub open {
     # Because we do rename(2) atomically, temporary file must be in same
     # partion with target file.
     my $temp = mktemp("${path}.XXXXXX");
-    $self->_temp_file($temp);
-    $self->_target_file($path);
+    $self->temp_file($temp);
+    $self->target_file($path);
 
     copy_preserving_attr($path, $temp) if -f $path;
     if (exists $opt->{backup_dir}) {
         unless (-d $opt->{backup_dir}) {
             croak "no such directory: $opt->{backup_dir}";
         }
-        $self->_backup_dir($opt->{backup_dir});
+        $self->backup_dir($opt->{backup_dir});
     }
 
     $self->SUPER::open($temp, $mode) ? $self : undef;
@@ -65,13 +65,12 @@ sub _closed {
 
 sub close {
     my ($self, $die) = @_;
-    $self->sync() or croak "sync: $!";
     unless ($self->_closed(1)) {
         if ($self->SUPER::close()) {
 
-            $self->backup if ($self->_backup_dir && -f $self->_target_file);
+            $self->backup if (-f $self->target_file && $self->backup_dir);
 
-            rename($self->_temp_file, $self->_target_file)
+            rename($self->temp_file, $self->target_file)
                 or ($die ? croak "close (rename) atomic file: $!\n" : return);
         } else {
             $die ? croak "close atomic file: $!\n" : return;
@@ -83,9 +82,9 @@ sub close {
 sub copy_modown_to_temp {
     my($self) = @_;
 
-    my($mode, $uid, $gid) = (stat($self->_target_file))[2,4,5];
-    chown $uid, $gid, $self->_temp_file;
-    chmod $mode,      $self->_temp_file;
+    my($mode, $uid, $gid) = (stat($self->target_file))[2,4,5];
+    chown $uid, $gid, $self->temp_file;
+    chmod $mode,      $self->temp_file;
 }
 
 sub backup {
@@ -93,18 +92,16 @@ sub backup {
 
     require Path::Class;
     require POSIX;
-    require Time::HiRes;
 
-    my $basename = Path::Class::file($self->_target_file)->basename;
+    my $basename = Path::Class::file($self->target_file)->basename;
 
     my $backup_file;
     my $n = 0;
     while ($n < 7) {
-        $backup_file = sprintf("%s/%s_%s.%d_%d%s",
-                               $self->_backup_dir,
+        $backup_file = sprintf("%s/%s_%s_%d%s",
+                               $self->backup_dir,
                                $basename,
                                POSIX::strftime("%Y-%m-%d_%H%M%S",localtime()),
-                               (Time::HiRes::gettimeofday())[1],
                                $$,
                                ($n == 0 ? "" : ".$n"),
                               );
@@ -113,7 +110,7 @@ sub backup {
     }
     croak "already exists backup file: $backup_file" if -f $backup_file;
 
-    copy_preserving_attr($self->_target_file, $backup_file);
+    copy_preserving_attr($self->target_file, $backup_file);
 }
 
 
@@ -121,7 +118,7 @@ sub delete {
     my $self = shift;
     unless ($self->_closed(1)) {
         $self->SUPER::close();
-        return unlink($self->_temp_file);
+        return unlink($self->temp_file);
     }
     1;
 }
@@ -148,15 +145,6 @@ sub copy_preserving_attr {
 1;
 __END__
 
-=encoding utf-8
-
-=begin html
-
-<a href="https://travis-ci.org/hirose31/IO-File-AtomicChange"><img src="https://travis-ci.org/hirose31/IO-File-AtomicChange.png?branch=master" alt="Build Status" /></a>
-<a href="https://coveralls.io/r/hirose31/IO-File-AtomicChange?branch=master"><img src="https://coveralls.io/repos/hirose31/IO-File-AtomicChange/badge.png?branch=master" alt="Coverage Status" /></a>
-
-=end html
-
 =head1 NAME
 
 IO::File::AtomicChange - change content of a file atomically
@@ -167,23 +155,24 @@ truncate and write to temporary file. When you call $fh->close, replace
 target file with temporary file preserved permission and owner (if
 possible).
 
-    use IO::File::AtomicChange;
-    
-    my $fh = IO::File::AtomicChange->new("foo.conf", "w");
-    $fh->print("# create new file\n");
-    $fh->print("foo\n");
-    $fh->print("bar\n");
-    $fh->close; # MUST CALL close EXPLICITLY
+  use IO::File::AtomicChange;
+  
+  my $fh = IO::File::AtomicChange->new("foo.conf", "w");
+  $fh->print("# create new file\n");
+  $fh->print("foo\n");
+  $fh->print("bar\n");
+  $fh->close; # MUST CALL close EXPLICITLY
+
 
 If you specify "backup_dir", save original file into backup directory (like
 "/var/backup/foo.conf_YYYY-MM-DD_HHMMSS_PID") before replace.
 
-    my $fh = IO::File::AtomicChange->new("foo.conf", "a",
-                                         { backup_dir => "/var/backup/" });
-    $fh->print("# append\n");
-    $fh->print("baz\n");
-    $fh->print("qux\n");
-    $fh->close; # MUST CALL close EXPLICITLY
+  my $fh = IO::File::AtomicChange->new("foo.conf", "a",
+                                       { backup_dir => "/var/backup/" });
+  $fh->print("# append\n");
+  $fh->print("baz\n");
+  $fh->print("qux\n");
+  $fh->close; # MUST CALL close EXPLICITLY
 
 =head1 DESCRIPTION
 
@@ -198,18 +187,18 @@ IO::File::AtomicChange free you from such a painful situation and boring code.
 
 =head1 INTERNAL
 
-    * open
-      1. fix filename of temporary file by mktemp.
-      2. if target file already exists, copy target file to temporary file preserving permission and owner.
-      3. open temporary file and return its file handle.
-    
-    * write
-      1. write date into temporary file.
-    
-    * close
-      1. close temporary file.
-      2. if target file exists and specified "backup_dir" option, copy target file into backup directory preserving permission and owner, mtime.
-      3. rename temporary file to target file.
+  * open
+    1. fix filename of temporary file by mktemp.
+    2. if target file already exists, copy target file to temporary file preserving permission and owner.
+    3. open temporary file and return its file handle.
+  
+  * write
+    1. write date into temporary file.
+  
+  * close
+    1. close temporary file.
+    2. if target file exists and specified "backup_dir" option, copy target file into backup directory preserving permission and owner, mtime.
+    3. rename temporary file to target file.
 
 =head1 CAVEATS
 
@@ -228,9 +217,9 @@ kazuho gave me many shrewd advice.
 
 =head1 REPOSITORY
 
-L<https://github.com/hirose31/IO-File-AtomicChange>
+L<http://github.com/hirose31/p5-io-file-atomicchange/tree/master>
 
-  git clone git://github.com/hirose31/IO-File-AtomicChange.git
+  git clone git://github.com/hirose31/p5-io-file-atomicchange.git
 
 patches and collaborators are welcome.
 
@@ -247,6 +236,7 @@ it under the same terms as Perl itself.
 
 =cut
 
+
 =begin comment
 
 =head0 SPECIAL THANKS TO
@@ -268,15 +258,3 @@ typester recommended brand new style "SEE ALSO" section.
   * shared $tmp_fh globally?
 
 =end comment
-
-# for Emacsen
-# Local Variables:
-# mode: cperl
-# cperl-indent-level: 4
-# cperl-close-paren-offset: -4
-# cperl-indent-parens-as-block: t
-# indent-tabs-mode: nil
-# coding: utf-8
-# End:
-
-# vi: set ts=4 sw=4 sts=0 et ft=perl fenc=utf-8 ff=unix :
